pub enum FcsDataType {
I,
F,
D,
A,
}Expand description
The data type of the FCS file, which determines how event data is stored
FCS files can store data in different numeric formats. The most common is single-precision floating point (F), which is also the default.
Variants
I
Unsigned binary integer
F
Single-precision floating point (f32)
D
Double-precision floating point (f64)
A
ASCII-encoded string (not supported)
Implementations
Sourceimpl FcsDataType
impl FcsDataType
Sourcepub fn from_keyword_str(data_type: &str) -> Result<Self>
pub fn from_keyword_str(data_type: &str) -> Result<Self>
Matches the string pattern and returns the corresponding data type
Errors
Will return Err if data_type is not a valid data type (ASCII-encoded strings are not supported, but binary integers, single-precision floating point, and double-precision floating point are supported)
Sourcepub fn to_keyword_str(&self) -> &str
pub fn to_keyword_str(&self) -> &str
Returns the keyword string representation of the data type
Sourcepub const fn get_bytes_per_event(&self) -> usize
pub const fn get_bytes_per_event(&self) -> usize
Returns the number of bytes per event for the data type as an unsigned integer