pub enum StringKeyword {
Show 38 variants
CYT(Arc<str>),
FIL(Arc<str>),
GUID(Arc<str>),
BEGINDATETIME(Arc<str>),
ENDDATETIME(Arc<str>),
CARRIERID(Arc<str>),
CARRIERTYPE(Arc<str>),
LOCATIONID(Arc<str>),
PnN(Arc<str>),
PnS(Arc<str>),
PnF(Arc<str>),
PnType(Arc<str>),
PnDISPLAY(Arc<str>),
PnDET(Arc<str>),
PnTAG(Arc<str>),
PnANALYTE(Arc<str>),
PnFEATURE(Arc<str>),
FLOWRATE(Arc<str>),
VOL(Arc<str>),
ORIGINALITY(Arc<str>),
LastModifier(Arc<str>),
LastModified(Arc<str>),
DATE(Arc<str>),
BTIM(Arc<str>),
ETIM(Arc<str>),
MODE(Arc<str>),
PLATEID(Arc<str>),
PLATENAME(Arc<str>),
WELLID(Arc<str>),
GATE(Arc<str>),
GnF(Arc<str>),
GnN(Arc<str>),
GnP(Arc<str>),
GnR(Arc<str>),
GnS(Arc<str>),
GnT(Arc<str>),
GnV(Arc<str>),
Other(Arc<str>),
}Variants
CYT(Arc<str>)
The name of the cytometer used to acquire the data (FCS 1.0+)
FIL(Arc<str>)
The name of the file containing the dataset (FCS 1.0+)
GUID(Arc<str>)
The globally unique identifier for the dataset (FCS 2.0+)
BEGINDATETIME(Arc<str>)
Begin date and time of data acquisition (FCS 3.2+)
ENDDATETIME(Arc<str>)
End date and time of data acquisition (FCS 3.2+)
CARRIERID(Arc<str>)
Generic sample carrier identifier (FCS 3.2+, replaces $PLATEID)
CARRIERTYPE(Arc<str>)
Type of sample carrier (FCS 3.2+, replaces $PLATENAME)
LOCATIONID(Arc<str>)
Location identifier within carrier (FCS 3.2+, replaces $WELLID)
PnN(Arc<str>)
‘Short name’ for parameter n (FCS 1.0+)
PnS(Arc<str>)
Label name for parameter n (FCS 1.0+)
PnF(Arc<str>)
Name of the optical filter for parameter n (FCS 1.0+)
PnType(Arc<str>)
The FCS measurement signal types and evaluation features (e.g., area, height, or width) (FCS 1.0+)
PnDISPLAY(Arc<str>)
Display scale for parameter n - typically “LOG” for logarithmic or “LIN” for linear (FCS 1.0+)
Note: Some FCS files use this as a string, others as numeric. We store as string for flexibility.
PnDET(Arc<str>)
Detector name for parameter n (FCS 3.2+)
PnTAG(Arc<str>)
Dye specification for parameter n (FCS 3.2+)
PnANALYTE(Arc<str>)
Target molecule or process for parameter n (FCS 3.2+)
PnFEATURE(Arc<str>)
Evaluation features for parameter n (FCS 3.2+)
FLOWRATE(Arc<str>)
Acquisition flow rate setting (FCS 3.2+)
VOL(Arc<str>)
Sample volume (FCS 3.1+)
ORIGINALITY(Arc<str>)
Distinguish between original and altered data set (FCS 3.1+)
LastModifier(Arc<str>)
Who last modified the data set (FCS 3.1+)
LastModified(Arc<str>)
When the data set was last modified (FCS 3.1+)
DATE(Arc<str>)
Date of data acquisition
(FCS 2.0-3.1, deprecated in FCS 3.2 in favor of $BEGINDATETIME)
BTIM(Arc<str>)
Begin time of data acquisition
(FCS 2.0-3.1, deprecated in FCS 3.2 in favor of $BEGINDATETIME)
ETIM(Arc<str>)
End time of data acquisition
(FCS 2.0-3.1, deprecated in FCS 3.2 in favor of $ENDDATETIME)
MODE(Arc<str>)
Data acquisition mode
(FCS 2.0-3.1, deprecated in FCS 3.2, fixed to “L” list mode)
PLATEID(Arc<str>)
Plate identifier
(FCS 2.0-3.1, deprecated in FCS 3.2 in favor of $CARRIERID)
PLATENAME(Arc<str>)
Platform/plate name
(FCS 2.0-3.1, deprecated in FCS 3.2 in favor of $CARRIERTYPE)
WELLID(Arc<str>)
Well identifier
(FCS 2.0-3.1, deprecated in FCS 3.2 in favor of $LOCATIONID)
GATE(Arc<str>)
Gate definition
(FCS 2.0-3.1, removed in FCS 3.2)
GnF(Arc<str>)
Gate n optical filter
(FCS 2.0-3.1, removed in FCS 3.2)
GnN(Arc<str>)
Gate n short name
(FCS 2.0-3.1, removed in FCS 3.2)
GnP(Arc<str>)
Gate n population name
(FCS 2.0-3.1, removed in FCS 3.2)
GnR(Arc<str>)
Gate n range
(FCS 2.0-3.1, removed in FCS 3.2)
GnS(Arc<str>)
Gate n label name
(FCS 2.0-3.1, removed in FCS 3.2)
GnT(Arc<str>)
Gate n threshold
(FCS 2.0-3.1, removed in FCS 3.2)
GnV(Arc<str>)
Gate n voltage range
(FCS 2.0-3.1, removed in FCS 3.2)
Other(Arc<str>)
A catch-all for other keywords, to be stored as Arc