pub enum ParameterProcessing {
Raw,
Compensated,
Unmixed,
UnmixedCompensated,
}Expand description
Instructions for parameter processing transformations
These variants indicate what transformations should be applied to the data, not the current state of the data (which may already be processed). This is used to track the processing pipeline for parameters (compensation, unmixing, etc.)
Variants
Raw
Raw, unprocessed data from FCS file
Compensated
Compensated for spectral overlap
Unmixed
Spectrally unmixed
UnmixedCompensated
Both compensated and spectrally unmixed