write_fcs_file

Function write_fcs_file 

pub fn write_fcs_file(fcs: Fcs, path: impl AsRef<Path>) -> Result<()>
Write an FCS file to disk

Important: This function closes the memory-mapped file before writing. The original Fcs struct will no longer be able to access the original file after this operation, but the data is preserved in the DataFrame.

Arguments

  • fcs - The FCS struct to write (will consume the struct)
  • path - Output file path

Errors

Returns an error if:

  • The path is invalid
  • The file cannot be written
  • Metadata cannot be serialized