pub enum FcsDataType {
I,
F,
D,
A,
}Expand description
The data type of the FCS file, which determines how event data is stored
FCS files can store data in different numeric formats. The most common is single-precision floating point (F), which is also the default.
Variants
I
Unsigned binary integer
F
Single-precision floating point (f32)
D
Double-precision floating point (f64)
A
ASCII-encoded string (not supported)
Implementations
Sourceimpl FcsDataType
impl FcsDataType
Sourcepub fn from_keyword_str(data_type: &str) -> Result<Self>
pub fn from_keyword_str(data_type: &str) -> Result<Self>
Matches the string pattern and returns the corresponding data type
Errors
Will return Err if data_type is not a valid data type (ASCII-encoded strings are not supported, but binary integers, single-precision floating point, and double-precision floating point are supported)
Sourcepub fn to_keyword_str(&self) -> &str
pub fn to_keyword_str(&self) -> &str
Convert to the keyword string representation of the data type
Returns
The single letter as expected by FCS file format (I, F, D, A)
Sourcepub fn get_bytes_for_bits(&self, bits: usize) -> usize
pub fn get_bytes_for_bits(&self, bits: usize) -> usize
Returns the number of bytes for the data type based on the number of bits
This is used in conjunction with $PnB to determine the actual bytes per parameter.
For I (integer) type, the actual bytes depend on $PnB (e.g., 16 bits = 2 bytes, 32 bits = 4 bytes).
For F (float32), always 4 bytes.
For D (float64), always 8 bytes.
Arguments
bits- Number of bits from$PnBkeyword
Returns
Number of bytes for this data type with the given bit width