pub enum MixedKeyword {
PnCalibration(f32, String),
PnD(String, f32, f32),
PnE(f32, f32),
GnE(f32, f32),
RnW(Vec<f32>),
SPILLOVER {
n_parameters: usize,
parameter_names: Vec<String>,
matrix_values: Vec<f32>,
},
PnL(Vec<usize>),
}Variants
PnCalibration(f32, String)
Specifies the conversion of arbitrary signal units, recorded as parameter values (uncompensated or compensated) to some well defined unit. For example, mean equivalent soluble fluorochrome (MESF) or antibody molecules.
-
f1 - the number of calibrated units corresponding to a unit signal value of parameter n
-
str - name of the units corresponding to calibration value
Example: If the signal on parameter n has the scale value X then the calibrated value is X * f units
PnD(String, f32, f32)
Recommends visualization scale for parameter n.
- String is either “Linear” or “Logarithmic”.
- f1 and f2 parameter values are in “scale” units, not “channel” units, see below for details.
- For linear scaling:
- f1: Lower bound - the scale value corresponding to the left edge of the display
- f2: Upper bound - the scale value corresponding to the right edge of the display
- For logarithmic scaling:
- f1: Decades - The number of decades to display.
- f2: Offset - The scale value corresponding to the left edge of the display
Example: $P3D (Linear,0,1024)
- Specifies a linear display range with scale parameter values ranging from 0 to 1024.
Example: $P2D (Logarithmic,4,0.1)
- Specifies a logarithmic display ranging from 0.1 to 1000 (scale value), which is 4 decades of display width.
Example: $P1D (Logarithmic,5,0.01)
- Specifies a logarithmic display ranging from 0.01 to 1000 (scale value), which is 5 decades of display width.
Example: $P3B (8) | $P3R (256) | $P3G (4) | $P3E (0,0) | $P3D (Linear,0,32):
- This is a linear parameter with channel values going from 0 to 255 (
$P3R). Taking account the gain ($PnG), the scale values go from 0 to 64 (256/4 = 64). The $P3D specifies a linear display from 0 to 32 scale units, which only encompasses the bottom half of the collected data range on this scale.
Example: $P4B (16) | $P4R (1024) | $P4E (4,1) | $P4D (Linear,0,1000)
- Specifies a linear display, with channel values going from 0 to 1023 (
$P4R). Only the bottom 10th of the scale values shown. This will restrict the display to channel values between 0 and 768 (the bottom 3 decades), with channels being distributed exponentially in the linear display.
Example: $P4B (16) | $P4R (1024) | $P4E (4,1) | $P4D (Logarithmic,3,1):
- The display keyword specifies that the data should be shown in logarithmic scaling, with only the bottom 3 decades shown. This will restrict the display to channel values between 0 and 768 (1024*3/4).
PnE(f32, f32)
(f1, f2) -Amplification type for parameter n. (FCS 1.0+)
- f1 - number of logarithmic decades
- f2 - linear value obtained for a signal with log value = 0
- 0,0 when the parameter is Linear.
- Also 0,0 when floating-point data (
$DATATYPE= F or$DATATYPE= D) is stored. Example:$P3E (4,1)- 4 decades with offset of 1
GnE(f32, f32)
Gate n amplification type.
(FCS v2.0-3.1, deprecated)
RnW(Vec<f32>)
Region n width values - vector of width values for region boundaries
Example: $R1W (0.5,1.2,0.8) - Three width values
SPILLOVER
Spillover matrix for compensation
Format: n, [param_names…], [matrix_values…]
Example: $SPILLOVER/3,FL2-A,FL1-A,FL3-A,1.0,0.03,0.2,0.1,1.0,0.0,0.05,0,1.0
PnL(Vec<usize>)
Excitation wavelength(s) for parameter n in nanometers (FCS 1.0+, format updated in FCS 3.1)
Can contain single or multiple wavelengths for co-axial lasers
Example: $P3L (488) - single wavelength
Example: $P4L (488,532,633) - multiple co-axial lasers