Transformable

Trait Transformable 

pub trait Transformable {
    // Required methods
    fn transform(&self, value: &f32) -> f32;
    fn inverse_transform(&self, value: &f32) -> f32;
}
Trait for types that can transform values from raw to display scale

Transformations are typically applied when displaying data, not when storing it. This allows the raw data to remain unchanged while providing flexible visualization options.

Required Methods

fn transform(&self, value: &f32) -> f32

fn inverse_transform(&self, value: &f32) -> f32

Implementors